==> geant4.10.00.p04.tar.gz: geant4.10.00.p04/examples/.doxygen/Doxymodules_hadronic.h <==
// $Id: Doxymodules_hadronic.h 78005 2013-12-02 08:29:57Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_hadronic.h
/// \brief The page that defines the extended/hadronic examples modules 


/** @defgroup extended_hadronic hadronic
 *  Extended examples hadronic classes
 *  @{
 */

/** @defgroup extended_hadronic_Hadr00 Hadr00
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr00/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */

/** @defgroup extended_hadronic_Hadr01 Hadr01
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr01/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */

/** @defgroup extended_hadronic_Hadr02 Hadr02
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr02/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */

/** @defgroup extended_hadronic_Hadr03 Hadr03
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr03/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */

/** @defgroup extended_hadronic_Hadr04 Hadr04
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr04/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */

/** @defgroup extended_hadronic_Hadr05 Hadr05
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr05/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */
/** @} */

==> geant4.10.01.p01.tar.gz: geant4.10.01.p01/examples/.doxygen/Doxymodules_hadronic.h <==
// $Id: Doxymodules_hadronic.h 86514 2014-11-13 09:10:24Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_hadronic.h
/// \brief The page that defines the extended/hadronic examples modules 


/** @defgroup extended_hadronic hadronic
 *  Extended examples hadronic classes
 *  @{
 */

/** @defgroup extended_hadronic_FissionFragment FissionFragment
 *  Hadronic example FissionFragment
 *  @ingroup extended_hadronic
 *  @{
 */

  class FFActionInitialization {};
  class FFDetectorConstruction {};
  class FFPrimaryGeneratorAction {};
  class FFRunAction {};

/** @} */

/** @defgroup extended_hadronic_Hadr00 Hadr00
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr00/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */

/** @defgroup extended_hadronic_Hadr01 Hadr01
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr01/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */

/** @defgroup extended_hadronic_Hadr02 Hadr02
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr02/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */

/** @defgroup extended_hadronic_Hadr03 Hadr03
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr03/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */

/** @defgroup extended_hadronic_Hadr04 Hadr04
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr04/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */

/** @defgroup extended_hadronic_Hadr05 Hadr05
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr05/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */

/** @defgroup extended_hadronic_Hadr06 Hadr06
 *  The shared hadronic classes have their
 *  <a href="../html_Hadr05/html/index.html">standalone documentation </a>
 *  @ingroup extended_hadronic
 *  @{
 */

/** @} */
/** @} */
